'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _nattyFetch = require('natty-fetch');

var _nattyFetch2 = _interopRequireDefault(_nattyFetch);

var _Toast = require('saltui/lib/Toast');

var _Toast2 = _interopRequireDefault(_Toast);

var _variables = require('./variables');

var _variables2 = _interopRequireDefault(_variables);

var _loading = require('../loading/loading');

var _loading2 = _interopRequireDefault(_loading);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// See https://github.com/Jias/natty-fetch for more details.
var context = _nattyFetch2.default.context({
  mockUrlPrefix: _variables2.default.urlPrefix,
  urlPrefix: _variables2.default.urlPrefix,
  mock: _variables2.default.isDev,
  // jsonp: true,
  withCredentials: false,
  traditional: true,
  header: {
    Authorization: 'Bearer ' + getLoginUserInfo().token
  },
  data: {
    _tb_token_: ''
  },
  timeout: 0,
  didFetch: function didFetch() {
    return _Toast2.default.hide();
  },
  // 请按照需要开启
  fit: function fit(response) {
    return {
      success: response.success,
      content: response.content,
      error: {
        errorMsg: response.errorMsg,
        errorCode: response.errorCode,
        errorLevel: response.errorLevel
      }
    };
  }
});

context.create('FlowApproval', {
  getFlowClassify: {
    mockUrl: 'query/getFlowClassify.json',
    url: _variables2.default.URLS.getProcessClassifyTree,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getFavoriteProcessList: {
    mockUrl: 'query/getFavoriteProcessList.json',
    url: _variables2.default.URLS.getFavoriteProcessList,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getTransactionListDate: {
    mockUrl: 'query/getTransactionListDate.json',
    url: 'query/getTransactionListDate.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getFlowRecord: {
    mockUrl: 'query/getFlowRecord.json',
    url: 'query/getFlowRecord.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  currentUserInfo: {
    mockUrl: 'query/getUserInfo.json',
    url: _variables2.default.URLS.userInfo,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getRemindBadgeCount: {
    mockUrl: 'query/getRemindBadgeCount.json',
    url: _variables2.default.URLS.getRemindBadgeCount,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  // 获取首页常用流程的列表
  getCommonUseProcess: {
    mockUrl: 'query/getCommonUseProcess.json',
    url: _variables2.default.URLS.getCommonUseProcess,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {}
  },
  queryProcessInfo: {
    mockUrl: 'query/queryProcessInfo.json',
    url: _variables2.default.URLS.queryProcessInfo,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  operateProcess: {
    mockUrl: '',
    url: _variables2.default.URLS.operateProcess,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  operateCommonUseProcess: {
    mockUrl: '',
    url: _variables2.default.URLS.operateCommonUseProcess,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {
      // Toast.show({
      //     content: <Loading />,
      //     duration:800
      // });
    }
  },
  batchFavoriteProcess: {
    mockUrl: '',
    url: _variables2.default.URLS.batchFavoriteProcess,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {}
  },
  queryProcessForm: {
    mockUrl: 'query/queryProcessForm.json',
    url: _variables2.default.URLS.queryProcessForm,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  signCA: {
    mockUrl: 'query/signCA.json',
    url: _variables2.default.URLS.signCA,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  verifySign: {
    mockUrl: 'query/verifySign.json',
    url: _variables2.default.URLS.verifySign,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  getPreTaskInfo: {
    mockUrl: 'query/getPreTaskInfo.json',
    url: _variables2.default.URLS.getPreTaskInfo,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  getApproveCount: {
    mockUrl: 'query/getApproveCount.json',
    url: _variables2.default.URLS.getApproveCount,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  }

});

//流程接口方法
context.create('FlowModuleAPI', {
  getSendFileInfo: {
    mockUrl: 'query/getSendFileInfo.json',
    url: _variables2.default.URLS.getSendFileInfo,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  startProcess: {
    url: _variables2.default.URLS.startProcess,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  sendFlow: {
    url: _variables2.default.URLS.sendFlow,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  saveForm: {
    url: _variables2.default.URLS.saveForm,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getReceiveFileInfo: {
    url: _variables2.default.URLS.getReceiveFileInfo,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  transferFlow: {
    url: _variables2.default.URLS.transferFlow,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  createReadTask: {
    url: _variables2.default.URLS.createReadTask,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  sendMail: {
    url: _variables2.default.URLS.sendMail,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  forwardReadTask: {
    url: _variables2.default.URLS.forwardReadTask,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  readCompleteTask: {
    url: _variables2.default.URLS.readCompleteTask,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  back: {
    url: _variables2.default.URLS.back,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  rollback: {
    url: _variables2.default.URLS.rollback,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  canRollback: {
    mockUrl: 'query/canRollback.json',
    url: _variables2.default.URLS.canRollback,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      // Toast.show({
      //   content: <Loading />
      // });
    }
  },
  getCanBackActivity: {
    mockUrl: 'query/queryCanBack.json',
    url: _variables2.default.URLS.getCanBackActivity,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      // Toast.show({
      //   content: <Loading />
      // });
    }
  },
  suspendProcess: {
    url: _variables2.default.URLS.suspendProcess,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  recall: {
    url: _variables2.default.URLS.recall,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getNextActivity: {
    mockUrl: 'query/getNextActivity.json',
    url: _variables2.default.URLS.getNextActivity,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  queryFlowChart: {
    mockUrl: 'query/queryFlowChart.json',
    url: _variables2.default.URLS.queryFlowChart,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  claimTask: {
    mockUrl: 'query/claimTask.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.claimTask,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  addSign: {
    mockUrl: 'query/addSign.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.addSign,
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getCanJumpActivity: {
    mockUrl: 'query/getCanJumpActivity.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getCanJumpActivity,
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  jump: {
    mockUrl: 'query/jump.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.jump,
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  urgeFlow: {
    mockUrl: '',
    url: _variables2.default.URLS.urgeFlow,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getDoneTaskListByProcessId: {
    mockUrl: 'query/getDoneTaskListByProcessId.json',
    url: _variables2.default.URLS.getDoneTaskListByProcessId,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getListButtonsByCodes: {
    mockUrl: 'query/getListButtonsByCodes.json',
    url: _variables2.default.URLS.getListButtonsByCodes,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {}
  },

  getProcessTitleByProId: {
    mockUrl: 'query/getProcessTitleByProId.json',
    url: _variables2.default.URLS.getProcessTitleByProId,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {}
  },

  getDocumentFileMap: {
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    mockUrl: 'query/getDocumentFileMap.json',
    url: _variables2.default.URLS.getDocumentFileMap,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  getLinkFieldValueMap: {
    mockUrl: 'query/getLinkFieldValueMap.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getLinkFieldValueMap,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  cancelProcess: {
    mockUrl: 'query/getDoneTaskListByProcessId.json',
    url: _variables2.default.URLS.cancelProcess,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  forceEnd: {
    mockUrl: 'query/getDoneTaskListByProcessId.json',
    url: _variables2.default.URLS.forceEnd,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getUndoTaskInfo: {
    mockUrl: 'query/getUndoTaskInfo.json',
    url: _variables2.default.URLS.getUndoTaskInfo,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  batchValidateForm: {
    mockUrl: 'query/batchValidateForm.json',
    url: _variables2.default.URLS.batchValidateForm,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  completeTaskBatch: {
    mockUrl: 'query/getDoneTaskListByProcessId.json',
    url: _variables2.default.URLS.completeTaskBatch,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  readCompleteTaskBatch: {
    mockUrl: 'query/getDoneTaskListByProcessId.json',
    url: _variables2.default.URLS.readCompleteTaskBatch,
    method: 'POST',
    postDataFomat: 'FORM',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getPersonalPhrase: {
    mockUrl: 'query/getPersonalPhrase.json',
    url: _variables2.default.URLS.getPersonalPhrase,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {}
  },
  getAllModuleList: {
    mockUrl: 'query/getAllModuleList.json',
    url: _variables2.default.URLS.getAllModuleList,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {}
  },
  getDelegateList: {
    mockUrl: 'query/getDelegateList.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getDelegateList,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  getDelegateViewInfo: {
    mockUrl: 'query/getDelegateViewInfo.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getDelegateViewInfo,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  getRelationProcess: {
    mockUrl: 'query/getRelationProcess.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getRelationProcess,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  getAllProcessList: {
    mockUrl: 'query/getAllProcessList.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.getAllProcessList,
    method: 'GET',
    willFetch: function willFetch() {}
  },
  savePersonalPhrase: {
    mockUrl: 'query/savePersonalPhrase.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.savePersonalPhrase,
    method: 'POST',
    postDataFomat: 'FORM',
    /*    header:{'content-Type':'application/x-www-form-urlencoded'},*/
    willFetch: function willFetch() {}
  },
  /* 删除常用语*/
  deletePhrase: {
    mockUrl: 'query/deletePhrase.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.deletePhrase,
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {}
  },
  deleteDelegate: {
    mockUrl: 'query/deleteDelegate.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.deleteDelegate,
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {}
  },
  editSaveDelegate: {
    mockUrl: 'query/editSaveDelegate.json',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    url: _variables2.default.URLS.editSaveDelegate,
    method: 'POST',
    postDataFomat: 'FORM',
    willFetch: function willFetch() {}
  }
});

context.create('form', {
  getFormContent: {
    mockUrl: 'query/getFormContent.json',
    url: _variables2.default.URLS.getFormContent,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getRelaFieldsMap: {
    mockUrl: 'query/getRelaFieldsMap.json',
    url: _variables2.default.URLS.getRelaFieldsMap,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    method: 'GET',
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  }
});

context.create('reactGrid', {
  getPortalPage: {
    mockUrl: 'query/reactGridInfo.json',
    url: _variables2.default.URLS.getPortalPage,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      // Toast.show({
      //   content: <Loading />,
      //   duration: 2000
      // });
    }
  },

  getComponentInfoListAll: {
    url: _variables2.default.URLS.getComponentInfoListAll,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  // 常用应用(频次)
  getNewComAppInfo: {
    url: _variables2.default.URLS.getNewComAppInfo,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  getNewHomePageTodoData: {
    // mockUrl: 'query/getNewHomePageTodoData.json',
    url: _variables2.default.URLS.getNewHomePageTodoData,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  getNewHomePageCollectAppInfoList: {
    url: _variables2.default.URLS.getNewHomePageCollectAppInfoList,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },

  getNewHomePageRemindCount: {
    // mockUrl: 'query/getNewHomePageRemindCount.json',
    url: _variables2.default.URLS.getNewHomePageRemindCount,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {}
  },
  getComAppInfo: {
    url: _variables2.default.URLS.getComAppInfo,
    method: 'GET',
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  }
});

context.create('portal', {
  getComponentInfoList: {
    mockUrl: 'query/getComponentInfoList.json',
    url: _variables2.default.URLS.getComponentInfoList,
    header: {
      Authorization: 'Bearer ' + getLoginUserInfo().token
    },
    willFetch: function willFetch() {
      _Toast2.default.show({
        content: _react2.default.createElement(_loading2.default, null),
        duration: 800
      });
    }
  },
  // 移动应用保存更新点击次数接口
  saveAppCount: {
    mockUrl: 'query/saveAppCount.json',
    url: _variables2.default.URLS.saveAppCount,
    method: 'POST',
    willFetch: function willFetch() {}
  }
});

exports.default = context.api;